pub struct ParseActionError(pub String);Expand description
Returned when a string cannot be parsed into an Action.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ParseActionError
impl Clone for ParseActionError
Sourcefn clone(&self) -> ParseActionError
fn clone(&self) -> ParseActionError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseActionError
impl Debug for ParseActionError
Sourceimpl Display for ParseActionError
impl Display for ParseActionError
impl Eq for ParseActionError
Sourceimpl Error for ParseActionError
impl Error for ParseActionError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ParseActionError
impl PartialEq for ParseActionError
Sourcefn eq(&self, other: &ParseActionError) -> bool
fn eq(&self, other: &ParseActionError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParseActionError